# Changelog

## [Unreleased]

## [0.60.0] - 2019-06-10

### Added

- `trainable` can be a list of prefixes of layer names

## [0.58.0] - 2019-06-10

### Fixed

- Use `math_ops` for tensorflow backend
- Assign names to variables in warmup optimizer 

## [0.56.0] - 2019-06-04

### Changed

- Docs about `training` and `trainable`

### Fixed

- Missing `trainable=False` when `training=True`

## [0.54.0] - 2019-05-29

### Added

- Support eager mode with tensorflow backend

## [0.43.0] - 2019-05-12

### Added

- Support `tf.keras`

## [0.40.0] - 2019-04-29

### Added

- Warmup optimizer

## [Older Versions]

### Added

- BERT implementation
- Load official model
- Tokenizer
- Demos
